@@ -137,6 +137,8 @@ static void game_generate_planets(struct game_s *g)
 
         p->look = rnd_0_nm1(2, &g->seed) * 6;
         p->frame = rnd_0_nm1(50, &g->seed);
+        /* Needed for the original sequence of random numbers */
+        /*p->field_16 =*/ rnd_0_nm1(4, &g->seed);
 
         in_nebula = false;
         for (int k = 0; k < g->nebula_num; ++k) {
@@ -315,9 +317,11 @@ static void game_generate_planets(struct game_s *g)
                 if (star_type == STAR_TYPE_RED) { di -= 4; } else if (star_type == STAR_TYPE_GREEN) { di -= 2; }
                 if (di <= 2) {
                     p->special = PLANET_SPECIAL_POOR;
-                    di = rnd_1_n(0x14, &g->seed);
-                    if (star_type == STAR_TYPE_RED) { di -= 4; } else if (star_type == STAR_TYPE_GREEN) { di -= 2; }
-                    if (di <= 5) {
+                }
+                di = rnd_1_n(0x14, &g->seed);
+                if (star_type == STAR_TYPE_RED) { di -= 4; } else if (star_type == STAR_TYPE_GREEN) { di -= 2; }
+                if (di <= 5) {
+                    if (p->special == PLANET_SPECIAL_POOR) {
                         p->special = PLANET_SPECIAL_ULTRA_POOR;
                     }
                 }
@@ -326,9 +330,11 @@ static void game_generate_planets(struct game_s *g)
             if (star_type == STAR_TYPE_BLUE) { di -= 2; } else if (star_type == STAR_TYPE_NEUTRON) { di -= 5; }
             if ((((int)PLANET_TYPE_STEPPE) - ((int)p->type)) > di) {
                 p->special = PLANET_SPECIAL_RICH;
-                di = rnd_1_n(0x14, &g->seed) - (in_nebula ? 8 : 0);
-                if (star_type == STAR_TYPE_BLUE) { di -= 2; } else if (star_type == STAR_TYPE_NEUTRON) { di -= 5; }
-                if (di < 6) {
+            }
+            di = rnd_1_n(0x14, &g->seed) - (in_nebula ? 8 : 0);
+            if (star_type == STAR_TYPE_BLUE) { di -= 2; } else if (star_type == STAR_TYPE_NEUTRON) { di -= 5; }
+            if (di < 6) {
+                if (p->special == PLANET_SPECIAL_RICH) {
                     p->special = PLANET_SPECIAL_ULTRA_RICH;
                 }
             }
@@ -509,14 +515,13 @@ static void game_generate_galaxy(struct game_s *g)
 
 static void game_generate_planet_names(struct game_s *g)
 {
-    BOOLVEC_DECLARE(in_use, PLANET_NAMES_MAX);
-    BOOLVEC_CLEAR(in_use, PLANET_NAMES_MAX);
+    BOOLVEC_DECLARE(in_use, PLANETS_MAX);
+    BOOLVEC_CLEAR(in_use, PLANETS_MAX);
     for (int i = 0; i < g->galaxy_stars; ++i) {
         uint16_t j;
-        j = rnd_0_nm1(PLANET_NAMES_MAX, &g->seed);
-        while (BOOLVEC_IS1(in_use, j)) {
-            if (++j == PLANET_NAMES_MAX) { j = 0; }
-        }
+        do {
+            j = rnd_0_nm1(PLANETS_MAX, &g->seed);
+        } while (BOOLVEC_IS1(in_use, j));
         BOOLVEC_SET1(in_use, j);
         lib_strcpy(g->planet[i].name, game_str_tbl_planet_names[j], PLANET_NAME_LEN);
     }
@@ -525,37 +530,31 @@ static void game_generate_planet_names(struct game_s *g)
 
 static void game_generate_race_banner(struct game_s *g)
 {
-    BOOLVEC_DECLARE(in_use, MAX((int)RACE_NUM, (int)BANNER_NUM));
+    const uint16_t race_tbl[] = {7, 1, 5, 0, 3, 9, 4, 6, 2, 8};
+    BOOLVEC_DECLARE(in_use, (int)BANNER_NUM);
     uint16_t loops;
     loops = 0;
-    BOOLVEC_CLEAR(in_use, MAX((int)RACE_NUM, (int)BANNER_NUM));
     for (player_id_t i = PLAYER_0; i < g->players; ++i) {
         race_t race;
+        bool in_use = false;
         race = g->eto[i].race;
         if (race != RACE_RANDOM) {
-            BOOLVEC_SET1(in_use, race);
             continue;
         }
-        race = rnd_0_nm1(RACE_NUM, &g->seed);
-        if (BOOLVEC_IS0(in_use, race)) {
-            BOOLVEC_SET1(in_use, race);
-            g->eto[i].race = race;
-        } else {
-            --i; /* try again */
-            if (++loops == 100) {
-                for (race = 0; race < RACE_NUM; ++race) {
-                    if (BOOLVEC_IS0(in_use, race)) {
-                        BOOLVEC_SET1(in_use, race);
-                        g->eto[i].race = race;
-                        break;
-                    }
-                }
-                loops = 0;
+        race = race_tbl[rnd_0_nm1(RACE_NUM, &g->seed)];
+        for (player_id_t j = PLAYER_0; j < i; ++j) {
+            if (g->eto[j].race == race) {
+                in_use = true;
+                --i;
+                break;
             }
         }
+        if (!in_use) {
+            g->eto[i].race = race;
+        }
     }
     loops = 0;
-    BOOLVEC_CLEAR(in_use, MAX((int)RACE_NUM, (int)BANNER_NUM));
+    BOOLVEC_CLEAR(in_use, (int)BANNER_NUM);
     for (player_id_t i = PLAYER_0; i < g->players; ++i) {
         banner_t banner;
         banner = g->eto[i].banner;
@@ -585,10 +584,14 @@ static void game_generate_race_banner(struct game_s *g)
         if (IS_AI(g, i)) {
             race_t r;
             r = g->eto[i].race;
-            g->eto[i].trait1 = game_num_tbl_trait1[r][rnd_0_nm1(TRAIT1_TBL_NUM, &g->seed)];
             g->eto[i].trait2 = game_num_tbl_trait2[r][rnd_0_nm1(TRAIT2_TBL_NUM, &g->seed)];
         }
     }
+    for (player_id_t i = PLAYER_0; i < g->players; ++i) {
+        race_t r;
+        r = g->eto[i].race;
+        g->eto[i].trait1 = game_num_tbl_trait1[r][rnd_0_nm1(TRAIT1_TBL_NUM, &g->seed)];
+    }
 }
 
 static bool game_generate_home_improved_do_i(struct game_s *g, struct game_new_options_s *opts, uint8_t tblhome[], player_id_t i)
@@ -659,6 +662,7 @@ static bool game_generate_home_improved_do_i(struct game_s *g, struct game_new_o
 static bool game_generate_home_improved_do(struct game_s *g, struct game_new_options_s *opts, uint16_t tblhome[])
 {
     uint8_t homes[PLAYER_NUM] = { PLANET_NONE , PLANET_NONE , PLANET_NONE , PLANET_NONE , PLANET_NONE , PLANET_NONE };
+    game_generate_race_banner(g);
     bool result = game_generate_home_improved_do_i(g, opts, homes, PLAYER_0);
     for (int i = 0; i < PLAYER_NUM; ++i) {
         tblhome[i] = homes[i];
@@ -672,6 +676,7 @@ static bool game_generate_home_do(struct game_s *g, uint16_t tblhome[])
     bool flag_all_ok;
     flag_all_ok = false;
     loops = 0;
+    game_generate_race_banner(g);
     while ((!flag_all_ok) && (loops < 200)) {
         flag_all_ok = true;
         for (player_id_t i = PLAYER_0; i < g->players; ++i) {
@@ -792,7 +797,6 @@ static void game_generate_home_etc(struct game_s *g, struct game_new_options_s *
             flag_all_ok = game_generate_home_do(g, tblhome);
         }
     } while (!flag_all_ok);
-    game_generate_race_banner(g);   /* must be run once and before the home planet name copy below */
     for (player_id_t i = PLAYER_0; i < g->players; ++i) {
         planet_t *p;
         homei = tblhome[i];
@@ -838,10 +842,6 @@ static void game_generate_home_etc(struct game_s *g, struct game_new_options_s *
         }
         p->pop_prev = p->pop;
         game_new_generate_home_name(g->eto[i].race, p->name, PLANET_NAME_LEN);
-        g->seen[i][homei].owner = p->owner;
-        g->seen[i][homei].pop = p->pop;
-        g->seen[i][homei].bases = p->missile_bases;
-        g->seen[i][homei].factories = p->factories;
     }
     for (int j = 0; j < g->galaxy_stars; ++j) {
         player_id_t owner;
@@ -1047,6 +1047,7 @@ static void game_generate_load(struct game_s *g)
     game_update_tech_util(g);
     for (player_id_t pli = PLAYER_0; pli < g->players; ++pli) {
         game_update_eco_on_waste(g, pli, false);
+        game_update_seen_by_orbit(g, pli);
     }
     game_update_within_range(g);
     game_update_visibility(g);
@@ -1170,15 +1171,9 @@ int game_new_tutor(struct game_s *g, struct game_aux_s *gaux)
     opt.difficulty = DIFFICULTY_SIMPLE;
     opt.pdata[PLAYER_0].race = RACE_KLACKON;
     opt.pdata[PLAYER_0].banner = BANNER_WHITE;
-    opt.pdata[PLAYER_1].race = RACE_SAKKRA;
-    opt.pdata[PLAYER_1].banner = BANNER_YELLOW;
-    opt.pdata[PLAYER_2].race = RACE_PSILON;
-    opt.pdata[PLAYER_2].banner = BANNER_BLUE;
-    opt.pdata[PLAYER_3].race = RACE_SILICOID;
-    opt.pdata[PLAYER_3].banner = BANNER_GREEN;
     lib_strcpy(opt.pdata[PLAYER_0].playername, "Mr Tutor", EMPEROR_NAME_LEN);
     lib_strcpy(opt.pdata[PLAYER_0].homename, "SOL", PLANET_NAME_LEN);
-    opt.galaxy_seed = 180616000; /* FIXME Generates a map different from the original MOO v1.3 */
+    opt.galaxy_seed = 0xfda3f;
     return game_new(g, gaux, &opt);
 }
 
