@@ -39,6 +39,8 @@
 
 /* -------------------------------------------------------------------------- */
 
+int copyprot_status = 0;
+
 static void game_turn_limit_ships(struct game_s *g)
 {
     for (int ei = 0; ei < g->enroute_num; ++ei) {
@@ -1135,7 +1137,7 @@ static void game_turn_transport(struct game_s *g)
             }
             /*e2a4*/
             if (pop3 <= 0) {
-                if (IS_HUMAN(g, owner) || ((p->owner != PLAYER_NONE) && IS_HUMAN(g, p->owner))) {
+                if (IS_HUMAN(g, owner) || IS_HUMAN(g, p->owner)) {
                     char *buf = ui_get_strbuf();
                     const char *s;
                     if ((g->gaux->local_players == 1) && IS_HUMAN(g, owner)) {
@@ -1281,7 +1283,7 @@ static bool game_turn_check_end(struct game_s *g, struct game_end_s *ge)
                 } else if (pi2 == PLAYER_NONE) {
                     pi2 = i;
                 }
-                if (IS_HUMAN(g, i) && (good_planets[i] > 0)) {
+                if (IS_HUMAN(g, i) && (good_planets[i] > 0) && IS_ALIVE(g, i)) {
                     human_alive = true;
                 }
             }
@@ -1577,11 +1579,9 @@ struct game_end_s game_turn_process(struct game_s *g)
         BOOLVEC_TBL_COPY1(old_contact, g->eto[i].contact, i, PLAYER_NUM);
         old_focus[i] = g->planet_focus_i[i];
     }
-#if 0
     if ((g->year > 40) && (!rnd_0_nm1(30, &g->seed)) && (copyprot_status == 0)) {
         copyprot_status = 1;
     }
-#endif
     game_turn_countdown_ceasefire(g);
     game_turn_update_mood_blunder(g);
     game_update_have_reserve_fuel(g);
@@ -1655,6 +1655,9 @@ struct game_end_s game_turn_process(struct game_s *g)
     if (game_event_run(g, &game_end)) {
         return game_end;
     }
+    if (game_turn_check_end(g, &game_end)) {
+        return game_end;
+    }
     for (int pli = 0; pli < g->galaxy_stars; ++pli) {
         player_id_t looter;
         looter = g->planet[pli].artifact_looter;
@@ -1707,11 +1710,9 @@ struct game_end_s game_turn_process(struct game_s *g)
     }
     game_fleet_unrefuel(g);
     game_update_production(g);
-#if 0
     if (copyprot_status == 1) {
-        copyprotection_check();
+        ui_copyprotection_check(g);
     }
-#endif
     for (player_id_t i = PLAYER_0; i < g->players; ++i) {
         game_update_eco_on_waste(g, i, false);
     }
@@ -1721,11 +1722,11 @@ struct game_end_s game_turn_process(struct game_s *g)
         g->planet_focus_i[i] = old_focus[i]; /* FIXME should not be needed anymore */
     }
     ++g->year;
-#if 0
     if (copyprot_status == 1) {
-        copyprotection_lose(&game_end);
+        ui_copyprotection_lose(g, &game_end);
         return game_end;
     }
+#if 0
     game_turn_show_newships(g); /* handled in game_turn_start_messages */
 #endif
     /* MOO1 autosaves here every 5 turns */
