@@ -67,7 +67,7 @@ static struct sdl_video_s {
     bool shrink, enlarge;
     int last_resize_time;
 
-    void (*render)(int bufi);
+    void (*render)(const uint8_t *buf);
     void (*update)(void);
     void (*setpal)(const uint8_t *pal, int first, int num);
 
@@ -115,11 +115,11 @@ static void video_create_texture(void)
        is going to change frequently.
     */
     log_message("SDL_CreateTexture: source, %d, %d, %s\n",
-                video.bufw, video.bufh, scaling_quality_str);
+                video.blit_rect.w, video.blit_rect.h, scaling_quality_str);
     video.texture = SDL_CreateTexture(video.renderer,
                                       video.pixel_format,
                                       SDL_TEXTUREACCESS_STREAMING,
-                                      video.bufw, video.bufh);
+                                      video.blit_rect.w, video.blit_rect.h);
 }
 
 static void video_create_upscaled_texture(bool force)
@@ -149,15 +149,15 @@ static void video_create_upscaled_texture(bool force)
        of the texture, the rendered area is scaled down to fit. Calculate
        the actual dimensions of the rendered area.
     */
-    if (w * video.actualh < h * video.bufw) {
+    if (w * video.actualh < h * video.blit_rect.w) {
         /* Tall window. */
-        h = (w * video.actualh) / video.bufw;
+        h = (w * video.actualh) / video.blit_rect.w;
     } else {
         /* Wide window. */
-        w = (h * video.bufw) / video.actualh;
+        w = (h * video.blit_rect.w) / video.actualh;
     }
 
-    if ((w % video.bufw == 0) && (h % video.bufh == 0)) {
+    if ((w % video.blit_rect.w == 0) && (h % video.blit_rect.h == 0)) {
         if (video.texture_upscaled) {
             SDL_DestroyTexture(video.texture_upscaled);
             video.texture_upscaled = NULL;
@@ -171,8 +171,8 @@ static void video_create_upscaled_texture(bool force)
        If one screen dimension matches an integer multiple of the original
        resolution, there is no need to overscale in this direction.
     */
-    w_upscale = (w + video.bufw - 1) / video.bufw;
-    h_upscale = (h + video.bufh - 1) / video.bufh;
+    w_upscale = (w + video.blit_rect.w - 1) / video.blit_rect.w;
+    h_upscale = (h + video.blit_rect.h - 1) / video.blit_rect.h;
 
     /* Minimum texture dimensions of 320x200. */
     SETMAX(w_upscale, 1);
@@ -198,12 +198,12 @@ static void video_create_upscaled_texture(bool force)
     SDL_SetHint(SDL_HINT_RENDER_SCALE_QUALITY, "linear");
 
     log_message("SDL_CreateTexture: upscaled, %d, %d\n",
-                w_upscale * video.bufw, h_upscale * video.bufh);
+                w_upscale * video.blit_rect.w, h_upscale * video.blit_rect.h);
     video.texture_upscaled = SDL_CreateTexture(video.renderer,
                                 video.pixel_format,
                                 SDL_TEXTUREACCESS_TARGET,
-                                w_upscale * video.bufw,
-                                h_upscale * video.bufh
+                                w_upscale * video.blit_rect.w,
+                                h_upscale * video.blit_rect.h
                              );
 
 }
@@ -223,18 +223,19 @@ static void video_destroy_renderer(void)
 
 /* -------------------------------------------------------------------------- */
 
-static void video_render(int bufi)
+static void video_render(const uint8_t *buf)
 {
     if (video.noblit) {
         return;
     }
+    int w = video.screen->w, h = video.screen->h;
     int pitch = video.screen->pitch;
     Uint8 *p = (Uint8 *)video.screen->pixels;
-    uint8_t *q = video.buf[bufi];
-    for (int y = 0; y < video.bufh; ++y) {
-        memcpy(p, q, video.bufw);
+    const uint8_t *q = buf;
+    for (int y = 0; y < h; ++y) {
+        memcpy(p, q, w);
         p += pitch;
-        q += video.bufw;
+        q += w;
     }
 }
 
@@ -245,18 +246,18 @@ static void video_adjust_window_size(int *wptr, int *hptr)
 {
     if (hw_opt_aspect != 0) {
         int w = *wptr, h = *hptr;
-        if ((w * video.actualh) <= (h * video.bufw)) {
+        if ((w * video.actualh) <= (h * video.blit_rect.w)) {
             /* We round up window_height if the ratio is not exact; this leaves the result stable. */
-            h = (w * video.actualh + video.bufw - 1) / video.bufw;
+            h = (w * video.actualh + video.blit_rect.w - 1) / video.blit_rect.w;
         } else {
-            w = (h * video.bufw) / video.actualh;
+            w = (h * video.blit_rect.w) / video.actualh;
         }
         bool do_resize = false;
-        int scale = w / video.bufw;
+        int scale = w / video.blit_rect.w;
         if (video.shrink || video.enlarge) {
             if (video.shrink) {
                 --scale;
-                if (w % video.bufw) {
+                if (w % video.blit_rect.w) {
                     ++scale;
                 }
             } else {
@@ -277,7 +278,7 @@ static void video_adjust_window_size(int *wptr, int *hptr)
             if (scale <= 0) {
                 scale = 1;
             }
-            w = video.bufw * scale;
+            w = video.blit_rect.w * scale;
             h = video.actualh * scale;
         }
         *wptr = w;
@@ -502,7 +503,7 @@ static int video_sw_set(int w, int h)
             return -1;
         }
         video.pixel_format = SDL_GetWindowPixelFormat(video.window);
-        SDL_SetWindowMinimumSize(video.window, video.bufw, video.actualh);
+        SDL_SetWindowMinimumSize(video.window, video.blit_rect.w, video.actualh);
         SDL_SetWindowTitle(video.window, PACKAGE_NAME " " VERSION_STR);
         if (video.icon) {
             SDL_SetWindowIcon(video.window, video.icon);
@@ -543,7 +544,7 @@ static int video_sw_set(int w, int h)
            time this also defines the aspect ratio that is preserved while scaling
            and stretching the texture into the window.
         */
-        SDL_RenderSetLogicalSize(video.renderer, video.bufw, video.actualh);
+        SDL_RenderSetLogicalSize(video.renderer, video.blit_rect.w, video.actualh);
     } else {
         /* Use full window. */
         SDL_RenderSetViewport(video.renderer, NULL);
@@ -563,7 +564,7 @@ static int video_sw_set(int w, int h)
 
     /* Create the 8-bit paletted screenbuffer surface. */
     if (video.screen == NULL) {
-        video.screen = SDL_CreateRGBSurface(0, video.bufw, video.bufh, 8, 0, 0, 0, 0);
+        video.screen = SDL_CreateRGBSurface(0, video.blit_rect.w, video.blit_rect.h, 8, 0, 0, 0, 0);
         SDL_FillRect(video.screen, NULL, 0);
     }
     /* Format of interbuffer must match the screen pixel format
@@ -579,7 +580,7 @@ static int video_sw_set(int w, int h)
                 log_error("Unsupported bits per pixel: %d\n", bpp);
                 return -1;
             }
-            video.interbuffer = SDL_CreateRGBSurface(0, video.bufw, video.bufh, bpp, rmask, gmask, bmask, amask);
+            video.interbuffer = SDL_CreateRGBSurface(0, video.blit_rect.w, video.blit_rect.h, bpp, rmask, gmask, bmask, amask);
             if (video.interbuffer == NULL) {
                 log_message("SDL_CreateRGBSurface(): %s\n", SDL_GetError());
                 return -1;
@@ -696,8 +697,8 @@ int hw_video_init(int w, int h)
     video.setpal = video_setpal;
     video.blit_rect.x = 0;
     video.blit_rect.y = 0;
-    video.blit_rect.w = video.bufw;
-    video.blit_rect.h = video.bufh;
+    video.blit_rect.w = w;
+    video.blit_rect.h = h;
     hw_video_update_actual_h();
     SETMAX(h, video.actualh);
     if (video_check_opt_screen_winwh() == 0) {
