@@ -50,6 +50,7 @@ void ui_extra_toggle_preset(bool enabled)
     ui_space_combat_autoresolve = enabled;
     ui_sm_ships_enabled = enabled;
     ui_sm_distance_tooltip = enabled;
+    ui_tech_bonus_button = enabled;
     ui_sm_expanded_scroll = enabled;
     ui_sm_explicit_cursor_context = enabled;
     ui_sm_no_question_mark_cursor = enabled;
@@ -108,12 +109,14 @@ const struct cfg_items_s ui_cfg_items[] = {
     CFG_ITEM_BOOL("ui_sm_ships_enabled", &ui_sm_ships_enabled),
     CFG_ITEM_BOOL("sm_expanded_scroll", &ui_sm_expanded_scroll),
     CFG_ITEM_BOOL("sm_distance_tooltip", &ui_sm_distance_tooltip),
+    CFG_ITEM_BOOL("tech_bonus_button", &ui_tech_bonus_button),
     CFG_ITEM_BOOL("live_spy_reports", &ui_live_spy_reports),
     CFG_ITEM_BOOL("sm_no_question_mark_cursor", &ui_sm_no_question_mark_cursor),
     CFG_ITEM_BOOL("sm_explicit_cursor_context", &ui_sm_explicit_cursor_context),
     CFG_ITEM_BOOL("kbd_cursor_offset_fix", &ui_kbd_cursor_offset_fix),
     CFG_ITEM_BOOL("mouse_lmb_fix", &ui_mouse_lmb_fix),
     CFG_ITEM_BOOL("mouse_warp_disabled", &ui_mouse_warp_disabled),
+    CFG_ITEM_BOOL("copy_protection_disabled", &ui_copyprotection_disabled),
     CFG_ITEM_BOOL("sm_mouseover_focus", &ui_sm_mouseover_focus),
     CFG_ITEM_BOOL("sm_mouse_scroll", &ui_sm_mouse_scroll),
     CFG_ITEM_BOOL("kbd_cursor_keys_fix", &ui_kbd_cursor_keys_fix),
@@ -199,12 +202,14 @@ bool ui_space_combat_autoresolve = false;
 bool ui_sm_ships_enabled = false;
 bool ui_sm_expanded_scroll = false;
 bool ui_sm_distance_tooltip = false;
+bool ui_tech_bonus_button = false;
 bool ui_live_spy_reports = false;
 bool ui_sm_no_question_mark_cursor = false;
 bool ui_sm_explicit_cursor_context = false;
 bool ui_kbd_cursor_offset_fix = false;
 bool ui_mouse_lmb_fix = false;
 bool ui_mouse_warp_disabled = false;
+bool ui_copyprotection_disabled = false;
 bool ui_sm_mouseover_focus = false;
 bool ui_sm_mouse_scroll = false;
 bool ui_kbd_cursor_keys_fix = false;
