@@ -446,7 +446,7 @@ void ui_draw_text_overlay(int x, int y, const char *str)
     y1 = y + h + 5;
     SETMIN(y1, UI_VGA_H - 1);
     ui_draw_filled_rect(x0, y0, x1, y1, 0, ui_scale);
-    lbxfont_print_str_normal(x, y, str, UI_SCREEN_W, ui_scale);
+    lbxfont_print_str_normal(x + 1, y + 1, str, UI_SCREEN_W, ui_scale);
 }
 
 void ui_draw_box_grain(int x0, int y0, int x1, int y1, uint8_t color0, uint8_t color1, uint8_t ae, int scale)
@@ -632,15 +632,15 @@ void ui_draw_finish(void)
     ui_draw_finish_mode = 0;
 }
 
-void ui_draw_stars(int x, int y, int xoff1, int xoff2, struct draw_stars_s *s, int scale)
+void ui_draw_stars(int x, int y, int xoff1, int xoff2, int scale)
 {
     const int sx1[16] = { 2, 6, 30, 34, 48, 74, 88, 96, 99, 103, 119, 123, 136, 137, 152, 159 };
     const int sy1[16] = { 15, 2, 16, 24, 19, 4, 11, 23, 22, 10, 21, 11, 4, 12, 22, 10 };
     const int sx2[23] = { 0, 6, 11, 33, 36, 46, 52, 67, 84, 86, 91, 95, 98, 103, 107, 112, 123, 125, 139, 142, 148, 151, 159 };
     const int sy2[23] = { 22, 8, 18, 19, 3, 18, 7, 24, 14, 17, 11, 1, 13, 15, 5, 6, 19, 1, 13, 10, 6, 23, 13 };
     int xo1, xo2;
-    xo1 = (s->xoff1 + xoff1) % (320 / 2);
-    xo2 = (s->xoff2 + xoff1 * 2) % (320 / 2);
+    xo1 = (ui_data.gfx.draw_stars.xoff1 + xoff1) % (320 / 2);
+    xo2 = (ui_data.gfx.draw_stars.xoff2 + xoff1 * 2) % (320 / 2);
     if (((UI_SCREEN_W / 2) - xoff2) > xo1) {
         int tx = xo1 + xoff2;
         for (int i = 0; i < 16; ++i) {
@@ -691,7 +691,7 @@ void ui_draw_stars(int x, int y, int xoff1, int xoff2, struct draw_stars_s *s, i
     }
 }
 
-void ui_draw_set_stars_xoffs(struct draw_stars_s *s, bool flag_right)
+void ui_draw_set_stars_xoffs(bool flag_right)
 {
     int x1, x2;
     if (flag_right) {
@@ -701,8 +701,8 @@ void ui_draw_set_stars_xoffs(struct draw_stars_s *s, bool flag_right)
         x1 = 1;
         x2 = 2;
     }
-    s->xoff1 = (s->xoff1 + x1) % (UI_SCREEN_W / 2);
-    s->xoff2 = (s->xoff2 + x2) % (UI_SCREEN_W / 2);
+    ui_data.gfx.draw_stars.xoff1 = (ui_data.gfx.draw_stars.xoff1 + x1) % (UI_SCREEN_W / 2);
+    ui_data.gfx.draw_stars.xoff2 = (ui_data.gfx.draw_stars.xoff2 + x2) % (UI_SCREEN_W / 2);
 }
 
 void ui_draw_textbox_2str(const char *str1, const char *str2, int y0, int scale)
