@@ -297,14 +297,14 @@ static void gmap_draw_cb(void *vptr)
             lbxfont_print_str_normal(295, 127, game_str_gm_prod, UI_SCREEN_W, ui_scale);
             lbxfont_print_str_normal(295, 135, game_str_gm_tech, UI_SCREEN_W, ui_scale);
             lbxfont_print_str_normal(295, 143, game_str_gm_tech, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(292, 103, game_str_gm_1_3, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(292, 111, game_str_gm_1_2, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(295, 119, game_str_gm_2x, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(295, 127, game_str_gm_3x, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(295, 135, game_str_gm_2x, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(295, 143, game_str_gm_4x, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 103, game_str_gm_1_3, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 111, game_str_gm_1_2, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 119, game_str_gm_2x, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 127, game_str_gm_3x, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 135, game_str_gm_2x, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 143, game_str_gm_4x, UI_SCREEN_W, ui_scale);
             lbxfont_print_str_center(275, 152, game_str_gm_prodb1, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_center(276, 159, game_str_gm_prodb2, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_center(275, 159, game_str_gm_prodb2, UI_SCREEN_W, ui_scale);
             lbxfont_print_str_center(275, 166, game_str_gm_prodb3, UI_SCREEN_W, ui_scale);
             break;
         default:
@@ -341,10 +341,12 @@ static void gmap_draw_cb(void *vptr)
     } else {
         int x, y;
         x = (ui_data.starmap.x * 224) / g->galaxy_maxx + 7;
-        SETMAX(x, 7);
         y = (ui_data.starmap.y * 185) / g->galaxy_maxy + 7;
-        SETMAX(y, 7);
-        lbxgfx_draw_frame(x, y, ui_data.gfx.starmap.bmap, UI_SCREEN_W, ui_scale);
+        if (ui_sm_expanded_scroll) {
+            lbxgfx_draw_frame_offs(x, y, ui_data.gfx.starmap.bmap, GMAP_LIMITS, UI_SCREEN_W, ui_scale);
+        } else {
+            lbxgfx_draw_frame(x, y, ui_data.gfx.starmap.bmap, UI_SCREEN_W, ui_scale);
+        }
     }
 }
 
