@@ -111,10 +111,12 @@ static const char* mm_get_custom_special_value(int i) {
 
 static bool mm_enable_preset_classic(void) {
     ui_extra_toggle_preset(false);
+    return true;
 }
 
 static bool mm_enable_preset_1oom(void) {
     ui_extra_toggle_preset(true);
+    return true;
 }
 
 /* -------------------------------------------------------------------------- */
@@ -439,6 +441,7 @@ static void main_menu_make_options_addons_page(struct main_menu_data_s *d)
     menu_make_bool(menu_allocate_item(), "UI SM Ships", &ui_sm_ships_enabled, MOO_KEY_s);
     menu_make_bool(menu_allocate_item(), "Live Spy Reports", &ui_live_spy_reports, MOO_KEY_p);
     menu_make_bool(menu_allocate_item(), "SM Distance Tooltip", &ui_sm_distance_tooltip, MOO_KEY_t);
+    menu_make_bool(menu_allocate_item(), "UI Tech Bonus Button", &ui_tech_bonus_button, MOO_KEY_c);
     menu_make_bool(menu_allocate_item(), "Game Options Extra", &ui_game_opts_extra, MOO_KEY_a);
     menu_make_bool(menu_allocate_item(), "Load Options Extra", &ui_load_opts_extra, MOO_KEY_o);
     menu_make_back(menu_allocate_item());
@@ -456,6 +459,7 @@ static void main_menu_make_options_interface_page(struct main_menu_data_s *d)
     menu_make_bool(menu_allocate_item(), "Leaving Transport Fix", &game_planet_leaving_trans_fix, MOO_KEY_p);
     menu_make_bool(menu_allocate_item(), "Expanded Starmap Scroll", &ui_sm_expanded_scroll, MOO_KEY_e);
     menu_make_bool(menu_allocate_item(), "SM Mouseover Focus", &ui_sm_mouseover_focus, MOO_KEY_m);
+    menu_make_bool(menu_allocate_item(), "Skip Copy Protection", &ui_copyprotection_disabled, MOO_KEY_o);
     menu_make_back(menu_allocate_item());
 }
 
@@ -467,6 +471,7 @@ static void main_menu_make_options_rules_page(struct main_menu_data_s *d)
     menu_make_bool(menu_allocate_item(), "Monster Rest Attack", &game_num_monster_rest_att, MOO_KEY_m);
     menu_make_bool(menu_allocate_item(), "Population Tenths Fix", &game_num_pop_tenths_fix, MOO_KEY_o);
     menu_make_bool(menu_allocate_item(), "Retreat Redir Fix", &game_num_retreat_redir_fix, MOO_KEY_r);
+    menu_make_bool(menu_allocate_item(), "Ship Scanner Fix", &game_num_ship_scanner_fix, MOO_KEY_s);
     menu_make_back(menu_allocate_item());
 }
 
@@ -786,8 +791,6 @@ main_menu_action_t ui_main_menu(struct game_new_options_s *newopts, struct game_
                 }
                 break;
             case MAIN_MENU_ACT_QUIT_GAME:
-                hw_audio_music_fadeout();
-                ui_palette_fadeout_a_f_1();
                 flag_done = true;
                 break;
             default:
@@ -796,6 +799,10 @@ main_menu_action_t ui_main_menu(struct game_new_options_s *newopts, struct game_
         }
     }
     ui_sound_stop_music();
+    /* call run_starmap_exe */
+    if (ret != MAIN_MENU_ACT_QUIT_GAME) {
+        ui_palette_fadeout_19_19_1();
+    }
     free_mainmenu_data(&d);
     return ret;
 }
