@@ -409,12 +409,20 @@ void ui_starmap_draw_starmap(struct starmap_data_s *d)
         ly = 178 * ui_scale - 1;
         for (int yb = y0; yb < ly; yb += 200) {
             for (int xb = x0; xb < lx; xb += 320) {
-                lbxgfx_draw_frame_offs(xb, yb, ui_data.gfx.starmap.starbak2, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
+                if (ui_extra_enabled) {
+                    lbxgfx_draw_frame_offs(xb, yb, ui_data.gfx.starmap.starbak2, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
+                } else {
+                    lbxgfx_draw_frame_offs(xb, yb, ui_data.gfx.starmap.starback, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
+                }
             }
         }
         for (int yb = y1; yb < ly; yb += 200) {
             for (int xb = x1; xb < lx; xb += 320) {
-                lbxgfx_draw_frame_offs(xb, yb, ui_data.gfx.starmap.starback, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
+                if (ui_extra_enabled) {
+                    lbxgfx_draw_frame_offs(xb, yb, ui_data.gfx.starmap.starback, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
+                } else {
+                    lbxgfx_draw_frame_offs(xb, yb, ui_data.gfx.starmap.starbak2, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
+                }
             }
         }
     }
@@ -541,7 +549,7 @@ void ui_starmap_draw_starmap(struct starmap_data_s *d)
         const planet_t *p = &g->planet[g->planet_focus_i[d->api]];
         tx = (p->x - x) * 2 + 8;
         ty = (p->y - y) * 2 + 8;
-        lbxgfx_draw_frame_offs(tx, ty, ui_data.gfx.starmap.planbord, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
+        lbxgfx_draw_frame_offs_delay(tx, ty, !(d->anim_delay % STARMAP_ANIM_DELAY), ui_data.gfx.starmap.planbord, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
     }
     if (d->anim_delay == 0) {
         if (--ui_data.starmap.line_anim_phase < 0) {
@@ -683,11 +691,13 @@ void ui_starmap_draw_scanner(struct starmap_data_s *d)
     for (int f = 0; f <= d->frame_scanner; ++f) {
         lbxgfx_draw_frame(227, 8, ui_data.gfx.starmap.scanner, UI_SCREEN_W, ui_scale);
     }
-    if (d->scanner_delay == 0) {
-        d->frame_scanner = (d->frame_scanner + 1) % 20;
-        ++d->scanner_delay;
-    } else {
-        d->scanner_delay = 0;
+    if (!(d->anim_delay % STARMAP_ANIM_DELAY)) {
+        if (d->scanner_delay == 0) {
+            d->frame_scanner = (d->frame_scanner + 1) % 20;
+            ++d->scanner_delay;
+        } else {
+            d->scanner_delay = 0;
+        }
     }
 }
 
@@ -1163,8 +1173,8 @@ void ui_starmap_draw_planetinfo_2(const struct game_s *g, int p1, int p2, int pl
     player_id_t api = (p1 < PLAYER_NUM) ? p1 : p2;
     bool explored = true;
     if (0
-      || ((p1 < PLAYER_NUM) && IS_HUMAN(g, p1) && BOOLVEC_IS0(p->explored, p1))
-      || ((p2 < PLAYER_NUM) && IS_HUMAN(g, p2) && BOOLVEC_IS0(p->explored, p2))
+      || (IS_HUMAN(g, p1) && BOOLVEC_IS0(p->explored, p1))
+      || (IS_HUMAN(g, p2) && BOOLVEC_IS0(p->explored, p2))
     ) {
         explored = false;
     }
