@@ -44,13 +44,12 @@ static void ui_starmap_orbit_own_draw_cb(void *vptr)
     char buf[0x80];
     STARMAP_LIM_INIT();
 
-    ui_starmap_draw_starmap(d);
-    ui_starmap_draw_button_text(d, true);
+    ui_starmap_draw_basic(d);
     {
         int x, y;
         x = (pf->x - ui_data.starmap.x) * 2 + 23;
         y = (pf->y - ui_data.starmap.y) * 2 + 5;
-        lbxgfx_draw_frame_offs(x, y, ui_data.gfx.starmap.shipbord, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
+        lbxgfx_draw_frame_offs_delay(x, y, !(d->anim_delay % STARMAP_ANIM_DELAY), ui_data.gfx.starmap.shipbord, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
     }
     ui_draw_filled_rect(225, 8, 314, 192, 7, ui_scale);
     lbxgfx_draw_frame(224, 5, ui_data.gfx.starmap.move_shi, UI_SCREEN_W, ui_scale);
@@ -68,7 +67,7 @@ static void ui_starmap_orbit_own_draw_cb(void *vptr)
         uint8_t *gfx;
         x1 = (pt->x - ui_data.starmap.x) * 2 + 8;
         y1 = (pt->y - ui_data.starmap.y) * 2 + 8;
-        lbxgfx_draw_frame_offs(x1, y1, ui_data.gfx.starmap.planbord, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
+        lbxgfx_draw_frame_offs_delay(x1, y1, !(d->anim_delay % STARMAP_ANIM_DELAY), ui_data.gfx.starmap.planbord, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
         x0 = (pf->x - ui_data.starmap.x) * 2 + 26;
         y0 = (pf->y - ui_data.starmap.y) * 2 + 8;
         ctbl = ui_starmap_orbit_own_in_frange(d, g->planet_focus_i[d->api]) ? colortbl_line_green : colortbl_line_red;
@@ -122,14 +121,13 @@ static void ui_starmap_orbit_own_draw_cb(void *vptr)
     }
     for (int i = 0; i < d->oo.sn0.num; ++i) {
         const shipdesign_t *sd = &(g->srd[d->api].design[0]);
-        struct draw_stars_s ds;
         uint8_t *gfx;
         int st;
         ui_draw_filled_rect(227, 22 + i * 26, 259, 46 + i * 26, 0, ui_scale);
         ui_draw_filled_rect(264, 34 + i * 26, 310, 46 + i * 26, 0, ui_scale);
-        ds.xoff1 = 0;
-        ds.xoff2 = 0;
-        ui_draw_stars(227, 22 + i * 26, 0, 32, &ds, ui_scale);
+        ui_data.gfx.draw_stars.xoff1 = 0;
+        ui_data.gfx.draw_stars.xoff2 = 0;
+        ui_draw_stars(227, 22 + i * 26, 0, 32, ui_scale);
         st = d->oo.sn0.type[i];
         gfx = ui_data.gfx.ships[sd[st].look];
         lbxgfx_set_frame_0(gfx);
